__gcc_v4sf __builtin_shufflevector(__gcc_v4sf, __gcc_v4sf, ...);

int __builtin_flt_rounds(void);
